@@ -248,7 +248,7 @@ STATIC int scan_lineFREE(lprec *lp, int section, char* line, char *field1, char
                          double *field4, char *field5, double *field6)
 {
   int  items = 0, line_len, len;
-  char buf[256], *ptr1, *ptr2;
+  char buf[256], *ptr1 = NULL, *ptr2;
 
   line_len = (int) strlen(line);
   while ((line_len) && ((line[line_len-1] == '\n') || (line[line_len-1] == '\r') || (line[line_len-1] == ' ')))
@@ -448,7 +448,7 @@ STATIC int scan_lineFREE(lprec *lp, int section, char* line, char *field1, char
   return(items);
 }
 
-STATIC int addmpscolumn(lprec *lp, MYBOOL Int_section, MYBOOL *Column_ready,
+STATIC int addmpscolumn(lprec *lp, MYBOOL Int_section, int typeMPS, MYBOOL *Column_ready,
                         int *count, REAL *Last_column, int *Last_columnno, char *Last_col_name)
 {
   int ok = TRUE;
@@ -458,8 +458,11 @@ STATIC int addmpscolumn(lprec *lp, MYBOOL Int_section, MYBOOL *Column_ready,
     if (ok) {
       ok = set_col_name(lp, lp->columns, Last_col_name);
     }
-    if (ok)
+    if (ok) {
       set_int(lp, lp->columns, Int_section);
+      if ((Int_section) && (typeMPS & MPSIBM))
+        set_bounds(lp, lp->columns, 10.0 / DEF_INFINITE, DEF_INFINITE / 10.0);
+    }
   }
   *Column_ready = FALSE;
   *count = 0;
@@ -562,17 +565,15 @@ MYBOOL __WINAPI MPS_readex(lprec **newlp, void *userhandle, read_modeldata_func
   else
     lp = *newlp;
 
-  switch(typeMPS) {
-    case MPSFIXED:
-      scan_line = scan_lineFIXED;
-      break;
-    case MPSFREE:
-      scan_line = scan_lineFREE;
-      break;
-    default:
-      report(lp, IMPORTANT, "MPS_readfile: Unrecognized MPS line type.\n");
+  if((typeMPS & MPSFIXED) == MPSFIXED)
+    scan_line = scan_lineFIXED;
+  else if((typeMPS & MPSFREE) == MPSFREE)
+    scan_line = scan_lineFREE;
+  else {
+    report(lp, IMPORTANT, "MPS_readfile: Unrecognized MPS line type.\n");
+    if (*newlp == NULL)
       delete_lp(lp);
-      return( CompleteStatus );
+    return( CompleteStatus );
   }
 
   if (lp != NULL) {
@@ -611,11 +612,11 @@ MYBOOL __WINAPI MPS_readex(lprec **newlp, void *userhandle, read_modeldata_func
           if (!set_lp_name(lp, probname))
             break;
         }
-        else if((typeMPS == MPSFREE) && (strcmp(tmp, "OBJSENSE") == 0)) {
+        else if(((typeMPS & MPSFREE) == MPSFREE) && (strcmp(tmp, "OBJSENSE") == 0)) {
           section = MPSOBJSENSE;
           report(lp, FULL, "Switching to OBJSENSE section\n");
         }
-        else if((typeMPS == MPSFREE) && (strcmp(tmp, "OBJNAME") == 0)) {
+        else if(((typeMPS & MPSFREE) == MPSFREE) && (strcmp(tmp, "OBJNAME") == 0)) {
           section = MPSOBJNAME;
           report(lp, FULL, "Switching to OBJNAME section\n");
         }
@@ -633,7 +634,7 @@ MYBOOL __WINAPI MPS_readex(lprec **newlp, void *userhandle, read_modeldata_func
           report(lp, FULL, "Switching to COLUMNS section\n");
         }
         else if(strcmp(tmp, "RHS") == 0) {
-          if (!addmpscolumn(lp, Int_section, &Column_ready, &count, Last_column, Last_columnno, Last_col_name))
+          if (!addmpscolumn(lp, Int_section, typeMPS, &Column_ready, &count, Last_column, Last_columnno, Last_col_name))
             break;
           section = MPSRHS;
           report(lp, FULL, "Switching to RHS section\n");
@@ -763,7 +764,7 @@ MYBOOL __WINAPI MPS_readex(lprec **newlp, void *userhandle, read_modeldata_func
                 }
 
                 if(Column_ready) {  /* Added ability to handle non-standard "same as above" column name */
-                  if (addmpscolumn(lp, Int_section, &Column_ready, &count, Last_column, Last_columnno, Last_col_name)) {
+                  if (addmpscolumn(lp, Int_section, typeMPS, &Column_ready, &count, Last_column, Last_columnno, Last_col_name)) {
                     strcpy(Last_col_name, field2);
                     NZ = 0;
                   }
@@ -837,11 +838,15 @@ MYBOOL __WINAPI MPS_readex(lprec **newlp, void *userhandle, read_modeldata_func
           }
 
           if((row = find_row(lp, field3, Unconstrained_rows_found)) >= 0) {
+            if ((row == 0) && ((typeMPS & MPSNEGOBJCONST) == MPSNEGOBJCONST))
+              field4 = -field4;
             set_rh(lp, row, (REAL)field4);
           }
 
           if(items == 6) {
             if((row = find_row(lp, field5, Unconstrained_rows_found)) >= 0) {
+              if ((row == 0) && ((typeMPS & MPSNEGOBJCONST) == MPSNEGOBJCONST))
+                field6 = -field6;
               set_rh(lp, row, (REAL)field6);
             }
           }
@@ -859,7 +864,7 @@ MYBOOL __WINAPI MPS_readex(lprec **newlp, void *userhandle, read_modeldata_func
           var = find_var(lp, field3, FALSE);
           if(var < 0){ /* bound on undefined var in COLUMNS section ... */
             Column_ready = TRUE;
-            if (!addmpscolumn(lp, FALSE, &Column_ready, &count, Last_column, Last_columnno, field3))
+            if (!addmpscolumn(lp, FALSE, typeMPS, &Column_ready, &count, Last_column, Last_columnno, field3))
               break;
             Column_ready = TRUE;
             var = find_var(lp, field3, TRUE);
@@ -1110,7 +1115,7 @@ MYBOOL __WINAPI MPS_readex(lprec **newlp, void *userhandle, read_modeldata_func
             var = find_var(lp, field, FALSE);  /* Native lp_solve and XPRESS formats */
             if(var < 0){ /* SOS on undefined var in COLUMNS section ... */
               Column_ready = TRUE;
-              if (!addmpscolumn(lp, FALSE, &Column_ready, &count, Last_column, Last_columnno, field))
+              if (!addmpscolumn(lp, FALSE, typeMPS, &Column_ready, &count, Last_column, Last_columnno, field))
                 break;
               Column_ready = TRUE;
               var = find_var(lp, field, TRUE);
@@ -1135,10 +1140,29 @@ MYBOOL __WINAPI MPS_readex(lprec **newlp, void *userhandle, read_modeldata_func
       CompleteStatus = FALSE;
     }
 
-    if(CompleteStatus == FALSE)
-      delete_lp(lp);
-    else
+    if(CompleteStatus == FALSE) {
+      if (*newlp == NULL)
+        delete_lp(lp);
+    }
+    else {
+      if (typeMPS & MPSIBM) {
+        REAL lower, upper;
+
+        for (var = 1; var <= lp->columns; var++)
+          if (is_int(lp, var)) {
+            lower = get_lowbo(lp, var);
+            upper = get_upbo(lp, var);
+            if ((lower == 10.0 / DEF_INFINITE) && (upper == DEF_INFINITE / 10.0))
+              upper = 1.0;
+            if (lower == 10.0 / DEF_INFINITE)
+              lower = 0.0;
+            if (upper == DEF_INFINITE / 10.0)
+              upper = lp->infinite;
+            set_bounds(lp, var, lower, upper);
+          }
+      }
       *newlp = lp;
+    }
     if(Last_column != NULL)
       FREE(Last_column);
     if(Last_columnno != NULL)
@@ -1148,7 +1172,7 @@ MYBOOL __WINAPI MPS_readex(lprec **newlp, void *userhandle, read_modeldata_func
   return( CompleteStatus );
 }
 
-static void number(char *str,REAL value)
+static void number(char *str,REAL value,int l)
  {
   char __str[80], *_str;
   int  i;
@@ -1157,34 +1181,34 @@ static void number(char *str,REAL value)
   _str=__str+2;
   if (value>=0.0)
    if ((value!=0.0) && ((value>0.99999999e12) || (value<0.0001))) {
-    int n=15;
+    int n=l+3;
 
     do {
      n--;
-     i=sprintf(_str,"%*.*E",n,n-6,(double) value);
-     if (i>12) {
+     i=sprintf(_str,"%*.*E",n,n-(l-6),(double) value);
+     if (i>l) {
       char *ptr=strchr(_str,'E');
 
       if (ptr!=NULL) {
        if (*(++ptr)=='-') ptr++;
-       while ((i>12) && ((*ptr=='+') || (*ptr=='0'))) {
+       while ((i>l) && ((*ptr=='+') || (*ptr=='0'))) {
         strcpy(ptr,ptr+1);
         i--;
        }
       }
      }
-    } while (i>12);
+    } while (i>l);
    }
    else if (value>=1.0e10) {
-    int n=13;
+    int n=l+1;
 
     do {
      i=sprintf(_str,"%*.0f",--n,(double) value);
-    } while (i>12);
+    } while (i>l);
    }
    else {
-    if (((i=sprintf(_str,"%12.10f",(double) value))>12) && (_str[12]>='5')) {
-     for (i=11;i>=0;i--)
+    if (((i=sprintf(_str,"%*.*f",l,l-2,(double) value))>l) && (_str[l]>='5')) {
+     for (i=l-1;i>=0;i--)
       if (_str[i]!='.') {
        if (++_str[i]>'9') _str[i]='0';
        else break;
@@ -1197,34 +1221,34 @@ static void number(char *str,REAL value)
    }
   else
    if ((value<-0.99999999e11) || (value>-0.0001)) {
-    int n=15;
+    int n=l+3;
 
     do {
      n--;
-     i=sprintf(_str,"%*.*E",n,n-7,(double) value);
-     if (i>12) {
+     i=sprintf(_str,"%*.*E",n,n-(l-5),(double) value);
+     if (i>l) {
       char *ptr=strchr(_str,'E');
 
       if (ptr!=NULL) {
        if (*(++ptr)=='-') ptr++;
-       while ((i>12) && ((*ptr=='+') || (*ptr=='0'))) {
+       while ((i>l) && ((*ptr=='+') || (*ptr=='0'))) {
         strcpy(ptr,ptr+1);
         i--;
        }
       }
      }
-    } while (i>12);
+    } while (i>l);
    }
    else if (value<=-1.0e9) {
-    int n=13;
+    int n=l+1;
 
     do {
      i=sprintf(_str,"%*.0f",--n,(double) value);
-    } while (i>12);
+    } while (i>l);
    }
    else
-    if (((i=sprintf(_str,"%12.9f",(double) value))>12) && (_str[12]>='5')) {
-     for (i=11;i>=1;i--)
+    if (((i=sprintf(_str,"%*.*f",l,l-3,(double) value))>l) && (_str[l]>='5')) {
+     for (i=l-1;i>=1;i--)
       if (_str[i]!='.') {
        if (++_str[i]>'9') _str[i]='0';
        else break;
@@ -1235,15 +1259,15 @@ static void number(char *str,REAL value)
       *(--_str)=' ';
      }
     }
-  strncpy(str,_str,12);
+  strncpy(str,_str,l);
  }
 
-static char *formatnumber12(char *numberbuffer, double a)
+static char *formatnumber(char *numberbuffer, double a, int l)
 {
 #if 0
   return(sprintf(numberbuffer, "%12g", a));
 #else
-  number(numberbuffer, a);
+  number(numberbuffer, a, l);
   return(numberbuffer);
 #endif
 }
@@ -1275,34 +1299,28 @@ static void write_data(void *userhandle, write_modeldata_func write_modeldata, c
 
 MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_modeldata_func write_modeldata)
 {
-  int    i, j, jj, je, k, marker, putheader, ChangeSignObj = FALSE, *idx, *idx1;
+  int    i, j, jj, je, k, marker, putheader, ChangeSignObj = FALSE, *idx, *idx1, l = 12;
   MYBOOL ok = TRUE, names_used;
   REAL   a, *val, *val1;
   char * (*MPSname)(char *name0, char *name);
-  char numberbuffer[15];
+  char numberbuffer[20];
   char name0[9];
 
-  if(lp->matA->is_roworder) {
-    report(lp, IMPORTANT, "MPS_writefile: Cannot write to MPS file while in row entry mode.\n");
-    return(FALSE);
+  if((typeMPS & MPSFIXED) == MPSFIXED) {
+    MPSname = MPSnameFIXED;
+    ChangeSignObj = is_maxim(lp);
   }
-
-  switch(typeMPS) {
-    case MPSFIXED:
-      MPSname = MPSnameFIXED;
-      ChangeSignObj = is_maxim(lp);
-      break;
-    case MPSFREE:
-      MPSname = MPSnameFREE;
-      break;
-    default:
-      report(lp, IMPORTANT, "MPS_writefile: unrecognized MPS name type.\n");
-      return(FALSE);
+  else if((typeMPS & MPSFREE) == MPSFREE) {
+    MPSname = MPSnameFREE;
+  }
+  else {
+    report(lp, IMPORTANT, "MPS_writefile: unrecognized MPS name type.\n");
+    return(FALSE);
   }
 
   names_used = lp->names_used;
 
-  if(typeMPS == MPSFIXED) {
+  if((typeMPS & MPSFIXED) == MPSFIXED) {
     /* Check if there is no variable name where the first 8 charachters are equal to the first 8 characters of anothe variable */
     if(names_used)
       for(i = 1; (i <= lp->columns) && (ok); i++)
@@ -1312,6 +1330,9 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
       if(strncmp(lp->col_name[i]->name, lp->col_name[j]->name, 8) == 0)
         ok = FALSE;
   }
+  else
+    if((typeMPS & MPSFREEFULLPRECISION) == MPSFREEFULLPRECISION)
+      l = 15;
 
   if(!ok) {
     lp->names_used = FALSE;
@@ -1338,7 +1359,7 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
 
   /* Write the MPS content */
   write_data(userhandle, write_modeldata, "NAME          %s\n", MPSname(name0, get_lp_name(lp)));
-  if((typeMPS == MPSFREE) && (is_maxim(lp)))
+  if(((typeMPS & MPSFREE) == MPSFREE) && (is_maxim(lp)))
     write_data(userhandle, write_modeldata, "OBJSENSE\n MAX\n");
   write_data(userhandle, write_modeldata, "ROWS\n");
   for(i = 0; i <= lp->rows; i++) {
@@ -1382,14 +1403,12 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
                           MPSname(name0, get_col_name(lp, i)));
           write_data(userhandle, write_modeldata, "  %s  %s",
                           MPSname(name0, get_row_name(lp, j)),
-/*                          formatnumber12(numberbuffer, (double) a)); */
-                          formatnumber12(numberbuffer, (double) (a * (j == 0 && ChangeSignObj ? -1 : 1))));
+                          formatnumber(numberbuffer, (double) (a * (j == 0 && ChangeSignObj ? -1 : 1)), l));
     }
         else
           write_data(userhandle, write_modeldata, "   %s  %s\n",
                           MPSname(name0, get_row_name(lp, j)),
-                          formatnumber12(numberbuffer, (double) (a * (j == 0 && ChangeSignObj ? -1 : 1))));
-/*                          formatnumber12(numberbuffer, (double) a)); */
+                          formatnumber(numberbuffer, (double) (a * (j == 0 && ChangeSignObj ? -1 : 1)), l));
       }
       if(k == 0)
         write_data(userhandle, write_modeldata, "\n");
@@ -1408,17 +1427,19 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
     a = lp->orig_rhs[i];
     if(a) {
       a = unscaled_value(lp, a, i);
+      if ((i == 0) && ((typeMPS & MPSNEGOBJCONST) == MPSNEGOBJCONST))
+        a = -a;
       if((i == 0) || is_chsign(lp, i))
         a = my_flipsign(a);
       k = 1 - k;
       if(k == 0)
         write_data(userhandle, write_modeldata, "    RHS       %s  %s",
                         MPSname(name0, get_row_name(lp, i)),
-                        formatnumber12(numberbuffer, (double)a));
+                        formatnumber(numberbuffer, (double)a, l));
       else
         write_data(userhandle, write_modeldata, "   %s  %s\n",
                         MPSname(name0, get_row_name(lp, i)),
-                        formatnumber12(numberbuffer, (double)a));
+                        formatnumber(numberbuffer, (double)a, l));
     }
   }
   if(k == 0)
@@ -1439,11 +1460,11 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
       if(k == 0)
         write_data(userhandle, write_modeldata, "    RGS       %s  %s",
                         MPSname(name0, get_row_name(lp, i)),
-                        formatnumber12(numberbuffer, (double)a));
+                        formatnumber(numberbuffer, (double)a, l));
       else
         write_data(userhandle, write_modeldata, "   %s  %s\n",
                         MPSname(name0, get_row_name(lp, i)),
-                        formatnumber12(numberbuffer, (double)a));
+                        formatnumber(numberbuffer, (double)a, l));
     }
   }
   if(k == 0)
@@ -1463,7 +1484,7 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
         }
         write_data(userhandle, write_modeldata, " FX BND       %s  %s\n",
                         MPSname(name0, get_col_name(lp, j)),
-                        formatnumber12(numberbuffer, (double)a));
+                        formatnumber(numberbuffer, (double)a, l));
       }
       else if(is_binary(lp, j)) {
         if(putheader) {
@@ -1482,7 +1503,15 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
                         MPSname(name0, get_col_name(lp, j)));
       }
       else {
-        if((lp->orig_lowbo[i] != 0) || (is_int(lp, j))) { /* Some solvers like CPLEX need to have a bound on a variable if it is integer, but not binary else it is interpreted as binary which is not ment */
+       int k1 = 1;
+       int k2 = 2;
+       
+       if(((typeMPS & MPSLINDO) == MPSLINDO) && (is_semicont(lp, j))) {
+         k1 = 2;
+         k2 = 1;
+       }
+       for (k = k1; k >= 1 && k <= 2; k += k2 - k1)
+        if((k == 1) && ((lp->orig_lowbo[i] != 0) || (is_int(lp, j)))) { /* Some solvers like CPLEX need to have a bound on a variable if it is integer, but not binary else it is interpreted as binary which is not ment */
           a = lp->orig_lowbo[i];
           a = unscaled_value(lp, a, i);
           if(putheader) {
@@ -1492,13 +1521,12 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
           if(lp->orig_lowbo[i] != -lp->infinite)
             write_data(userhandle, write_modeldata, " LO BND       %s  %s\n",
                             MPSname(name0, get_col_name(lp, j)),
-                            formatnumber12(numberbuffer, (double)a));
+                            formatnumber(numberbuffer, (double)a, l));
           else
             write_data(userhandle, write_modeldata, " MI BND       %s\n",
                             MPSname(name0, get_col_name(lp, j)));
         }
-
-        if((lp->orig_upbo[i] < lp->infinite) || (is_semicont(lp, j))) {
+        else if((k == 2) && ((lp->orig_upbo[i] < lp->infinite) || (is_semicont(lp, j)))) {
           a = lp->orig_upbo[i];
           if(a < lp->infinite)
             a = unscaled_value(lp, a, i);
@@ -1510,16 +1538,16 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
             if(is_int(lp, j))
               write_data(userhandle, write_modeldata, " SI BND       %s  %s\n",
                               MPSname(name0, get_col_name(lp, j)),
-                  (a < lp->infinite) ? formatnumber12(numberbuffer, (double)a) : "            ");
+                  (a < lp->infinite) ? formatnumber(numberbuffer, (double)a, l) : "            ");
             else
               write_data(userhandle, write_modeldata, " SC BND       %s  %s\n",
                               MPSname(name0, get_col_name(lp, j)),
-                              (a < lp->infinite) ? formatnumber12(numberbuffer, (double)a) : "            ");
+                              (a < lp->infinite) ? formatnumber(numberbuffer, (double)a, l) : "            ");
           }
           else
             write_data(userhandle, write_modeldata, " UP BND       %s  %s\n",
                             MPSname(name0, get_col_name(lp, j)),
-                            formatnumber12(numberbuffer, (double)a));
+                            formatnumber(numberbuffer, (double)a, l));
         }
       }
     }
@@ -1536,11 +1564,11 @@ MYBOOL __WINAPI MPS_writefileex(lprec *lp, int typeMPS, void *userhandle, write_
     write_data(userhandle, write_modeldata, " S%1d SOS       %s  %s\n",
                     SOS->sos_list[i]->type,
                     MPSname(name0, SOS->sos_list[i]->name),
-                    formatnumber12(numberbuffer, (double) SOS->sos_list[i]->priority));
+                    formatnumber(numberbuffer, (double) SOS->sos_list[i]->priority, l));
     for(j = 1; j <= SOS->sos_list[i]->size; j++) {
       write_data(userhandle, write_modeldata, "    SOS       %s  %s\n",
                       MPSname(name0, get_col_name(lp, SOS->sos_list[i]->members[j])),
-                      formatnumber12(numberbuffer, (double) SOS->sos_list[i]->weights[j]));
+                      formatnumber(numberbuffer, (double) SOS->sos_list[i]->weights[j], l));
     }
   }
 
@@ -1656,16 +1684,13 @@ MYBOOL MPS_readBAS(lprec *lp, int typeMPS, char *filename, char *info)
   int    (*scan_line)(lprec *lp, int section, char* line, char *field1, char *field2, char *field3,
                       double *field4, char *field5, double *field6);
 
-  switch(typeMPS) {
-    case MPSFIXED:
-      scan_line = scan_lineFIXED;
-      break;
-    case MPSFREE:
-      scan_line = scan_lineFREE;
-      break;
-    default:
-      report(lp, IMPORTANT, "MPS_readBAS: unrecognized MPS line type.\n");
-      return(FALSE);
+  if((typeMPS & MPSFIXED) == MPSFIXED)
+    scan_line = scan_lineFIXED;
+  else if((typeMPS & MPSFREE) == MPSFREE)
+    scan_line = scan_lineFREE;
+  else {
+    report(lp, IMPORTANT, "MPS_readBAS: unrecognized MPS line type.\n");
+    return(FALSE);
   }
 
   ok = (MYBOOL) ((filename != NULL) && ((input = fopen(filename,"r")) != NULL));
@@ -1715,7 +1740,7 @@ MYBOOL MPS_readBAS(lprec *lp, int typeMPS, char *filename, char *info)
       }
     }
     else { /* normal line, process */
-      items = scan_line(lp, MPSRHS, line, field1, field2, field3, &field4, field5, &field6);
+      items = scan_line(lp, /* MPSRHS */ MPSBOUNDS, line, field1, field2, field3, &field4, field5, &field6);
       if(items < 0){
         report(lp, IMPORTANT, "Syntax error on line %d: %s\n", Lineno, line);
         break;
@@ -1778,16 +1803,13 @@ MYBOOL MPS_writeBAS(lprec *lp, int typeMPS, char *filename)
   char name0[9];
 
   /* Set name formatter */
-  switch(typeMPS) {
-    case MPSFIXED:
-      MPSname = MPSnameFIXED;
-      break;
-    case MPSFREE:
-      MPSname = MPSnameFREE;
-      break;
-    default:
-      report(lp, IMPORTANT, "MPS_writeBAS: unrecognized MPS name type.\n");
-      return(FALSE);
+  if((typeMPS & MPSFIXED) == MPSFIXED)
+    MPSname = MPSnameFIXED;
+  else if((typeMPS & MPSFREE) == MPSFREE)
+    MPSname = MPSnameFREE;
+  else {
+    report(lp, IMPORTANT, "MPS_writeBAS: unrecognized MPS name type.\n");
+    return(FALSE);
   }
 
   /* Open the file for writing */
